==> apache-sedona-1.0.0-incubating-src.tar.gz: apache-sedona-1.0.0-incubating-src/docs/community/contact.md <==
# Community

Every volunteer project obtains its strength from the people involved in it. We invite you to participate as much or as little as you choose.

You can participate in the community as follows:

* Use our project and provide a feedback.
* Provide us with the use-cases.
* Report bugs and submit patches.
* Contribute code and documentation.

## Twitter

[Apache Sedona@Twitter](https://twitter.com/ApacheSedona)

## Gitter chat

[![Gitter](https://badges.gitter.im/apache/sedona.svg)](https://gitter.im/apache/sedona?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge)

## Mailing list

Get help using Sedona or contribute to the project on our mailing lists

[Sedona Mailing Lists](https://lists.apache.org/list.html?sedona.apache.org): 

* [dev@sedona.apache.org](https://lists.apache.org/list.html?dev@sedona.apache.org): project development and general questions

## Issue tracker

### Bug Reports

Found bug? Enter an issue in the [Sedona JIRA](https://issues.apache.org/jira/projects/SEDONA)

Before submitting an issue, please:

* Verify that the bug does in fact exist.
* Search the issue tracker to verify there is no existing issue reporting the bug you’ve found.
* Consider tracking down the bug yourself in the Wink’s source and submitting a patch along with your bug report. This is a great time saver for the Wink developers and helps ensure the bug will be fixed quickly.

### Feature Requests

Enhancement requests for new features are also welcome. The more concrete and rationale the request is, the greater the chance it will incorporated into future releases.

Enter an issue in the [Sedona JIRA](https://issues.apache.org/jira/projects/SEDONA) or send an email to [dev@sedona.apache.org](https://lists.apache.org/list.html?dev@sedona.apache.org)

==> apache-sedona-1.2.1-incubating-src.tar.gz: apache-sedona-1.2.1-incubating-src/docs/community/contact.md <==
# Community

Every volunteer project obtains its strength from the people involved in it. We invite you to participate as much or as little as you choose.

You can participate in the community as follows:

* Use our project and provide a feedback.
* Provide us with the use-cases.
* Report bugs and submit patches.
* Contribute code and documentation.

## Feedback

Feedback to improve Apache Sedona: [Google Form](https://docs.google.com/forms/d/e/1FAIpQLSeYHlc4cX5Pw0bIx2dQbhHDeWF2G2Wf7BgN_n29IzXsSzwptA/viewform)


## Twitter

[Apache Sedona@Twitter](https://twitter.com/ApacheSedona)

## Gitter chat

[![Gitter](https://badges.gitter.im/apache/sedona.svg)](https://gitter.im/apache/sedona?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge)

## Mailing list

Get help using Sedona or contribute to the project on our mailing lists

[Sedona Mailing Lists](https://lists.apache.org/list.html?sedona.apache.org): 

* [dev@sedona.apache.org](https://lists.apache.org/list.html?dev@sedona.apache.org): project development and general questions

## Issue tracker

### Bug Reports

Found bug? Enter an issue in the [Sedona JIRA](https://issues.apache.org/jira/projects/SEDONA)

Before submitting an issue, please:

* Verify that the bug does in fact exist.
* Search the issue tracker to verify there is no existing issue reporting the bug you’ve found.
* Consider tracking down the bug yourself in the Wink’s source and submitting a patch along with your bug report. This is a great time saver for the Wink developers and helps ensure the bug will be fixed quickly.

### Feature Requests

Enhancement requests for new features are also welcome. The more concrete and rationale the request is, the greater the chance it will incorporated into future releases.

Enter an issue in the [Sedona JIRA](https://issues.apache.org/jira/projects/SEDONA) or send an email to [dev@sedona.apache.org](https://lists.apache.org/list.html?dev@sedona.apache.org)
